# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic
Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Changed

### Deprecated

### Fixed

## [0.1.0] - 2024-09-11

Initial release.

[unreleased]: https://github.com/f-dangel/wandb_preempt/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/f-dangel/wandb_preempt/compare/ef3d15cf1474c2b780acad60a722f46880d43c84...v0.1.0
